==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkClipboard.h <==
// public class gnu.java.awt.peer.gtk.GtkClipboard

// class file dependencies
// @dep_class 612545906125a37 gnu_java_awt_peer_gtk_GtkClipboard
// @dep_class 8c335465665e3ddb java_awt_datatransfer_Clipboard
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_datatransfer_Clipboard

#include "java/awt/datatransfer/Clipboard.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_
#define _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_ClipboardOwner$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$refs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object	_jc_gnu_java_awt_peer_gtk_GtkClipboard$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct {
	struct _jc_java_lang_String$object	*selection;
	struct _jc_java_lang_Object$object	*selectionLock;
	jint	SELECTION__5fRECEIVED__5fTIMEOUT;
	jboolean	hasSelection;
};
extern _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkClipboard$method$getContents$3780cd97213b3b38(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$initNativeState$4dc9fc2b620185a0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$selectionClear$d31ccd20c78a7253(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$setContents$90a1004e60b7abaa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GtkClipboard$method$stringSelectionHandler$8904e5d807294412(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$stringSelectionReceived$6cfb48c1e2981515(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$getContents$3780cd97213b3b38;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$initNativeState$4dc9fc2b620185a0;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$selectionClear$d31ccd20c78a7253;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$setContents$90a1004e60b7abaa;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$stringSelectionHandler$8904e5d807294412;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$stringSelectionReceived$6cfb48c1e2981515;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$requestStringConversion$c13f62e175628784(_jc_env *);
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$selectionGet$9eec36ffd1fc6f55(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods {
	struct _jc_object	*(*getContents$3780cd97213b3b38)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_Object$object *);
	void	(*initNativeState$4dc9fc2b620185a0)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
	void	(*selectionClear$d31ccd20c78a7253)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
	void	(*setContents$90a1004e60b7abaa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*stringSelectionHandler$8904e5d807294412)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *);
	void	(*stringSelectionReceived$6cfb48c1e2981515)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_Clipboard$vmethods	java_awt_datatransfer_Clipboard;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods	gnu_java_awt_peer_gtk_GtkClipboard;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$refs {
    _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs	gnu_java_awt_peer_gtk_GtkClipboard;
    _jc_java_awt_datatransfer_Clipboard$sub_refs	java_awt_datatransfer_Clipboard;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	java_awt_datatransfer_Clipboard;
    _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs	gnu_java_awt_peer_gtk_GtkClipboard;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object {
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype _jc_gnu_java_awt_peer_gtk_GtkClipboard$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkClipboard, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkClipboard$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/peer/gtk/GtkClipboard.h <==
// public class gnu.java.awt.peer.gtk.GtkClipboard

// class file dependencies
// @dep_class 612545906125a37 gnu_java_awt_peer_gtk_GtkClipboard
// @dep_class 8c335465665e3ddb java_awt_datatransfer_Clipboard
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_datatransfer_Clipboard

#include "java/awt/datatransfer/Clipboard.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_
#define _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_ClipboardOwner$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$refs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object	_jc_gnu_java_awt_peer_gtk_GtkClipboard$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct {
	struct _jc_java_lang_String$object	*selection;
	struct _jc_java_lang_Object$object	*selectionLock;
	jint	SELECTION__5fRECEIVED__5fTIMEOUT;
	jboolean	hasSelection;
};
extern _jc_gnu_java_awt_peer_gtk_GtkClipboard$fields_struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkClipboard$method$getContents$3780cd97213b3b38(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$initNativeState$4dc9fc2b620185a0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$selectionClear$d31ccd20c78a7253(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$setContents$90a1004e60b7abaa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GtkClipboard$method$stringSelectionHandler$8904e5d807294412(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$stringSelectionReceived$6cfb48c1e2981515(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$getContents$3780cd97213b3b38;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$initNativeState$4dc9fc2b620185a0;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$selectionClear$d31ccd20c78a7253;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$setContents$90a1004e60b7abaa;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$stringSelectionHandler$8904e5d807294412;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkClipboard$method_info$stringSelectionReceived$6cfb48c1e2981515;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$requestStringConversion$c13f62e175628784(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkClipboard$method$selectionGet$9eec36ffd1fc6f55(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods {
	struct _jc_object	*(*getContents$3780cd97213b3b38)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*initNativeState$4dc9fc2b620185a0)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
	void	(*selectionClear$d31ccd20c78a7253)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
	void	(*setContents$90a1004e60b7abaa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*stringSelectionHandler$8904e5d807294412)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *) _JC_JCNI_ATTR;
	void	(*stringSelectionReceived$6cfb48c1e2981515)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_datatransfer_Clipboard$vmethods	java_awt_datatransfer_Clipboard;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vmethods	gnu_java_awt_peer_gtk_GtkClipboard;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$refs {
    _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_refs	gnu_java_awt_peer_gtk_GtkClipboard;
    _jc_java_awt_datatransfer_Clipboard$sub_refs	java_awt_datatransfer_Clipboard;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_datatransfer_Clipboard$sub_nonrefs	java_awt_datatransfer_Clipboard;
    _jc_gnu_java_awt_peer_gtk_GtkClipboard$sub_nonrefs	gnu_java_awt_peer_gtk_GtkClipboard;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkClipboard$object {
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkClipboard$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkClipboard$vtype _jc_gnu_java_awt_peer_gtk_GtkClipboard$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkClipboard, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkClipboard$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkClipboard_H_ */
